package com.muyu.common.core.web.model;

import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.muyu.common.core.web.page.PageDomain;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.List;

/**
 * @program: cloud-server
 * @description: 列表查询模型
 * @author: MengFanKuo
 * @create: 2024-11-20 20:28
 * *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
public class QueryModel<T> {
    /**
     * 当前记录起始索引
     */
    private Integer pageNum;
    /**
     * 每页显示记录数
     */
    private Integer pageSize;
    /**
     * 排序列
     */
    private String orderByColumn;
    /**
     * 排序的方向
     */
    private boolean isAsc= true;

    /**
     * 构建分页对象
     * @param pageDomain
     * @return
     */
    public T domainBuild(PageDomain pageDomain){
        this.isAsc="asc".equals(pageDomain.getIsAsc()) ? true : false;
        this.orderByColumn=pageDomain.getOrderByColumn();
        this.pageNum=pageDomain.getPageNum();
        this.pageSize=pageDomain.getPageSize();
        return (T) this;
    }

    /**
     * 构建分页查询对象
     * @return
     */
    public <T> Page<T> buildPage(){
        Page<T> page = Page.of(this.getPageNum(), this.getPageSize());
        page.setOrders(List.of(this.isAsc() ? OrderItem.asc(this.getOrderByColumn()) : OrderItem.asc(this.getOrderByColumn())));
        return page;
    }
}
