package com.muyu.product.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.GroupBuy;
import com.muyu.product.domain.req.GroupBuyQueryReq;
import com.muyu.product.domain.req.GroupBuySaveReq;
import com.muyu.product.domain.req.GroupBuyEditReq;
import com.muyu.product.service.GroupBuyService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author DongZeLiang
 * @date 2024-11-14
 */
@Api(tags = "拼团")
@RestController
@RequestMapping("/buy")
public class GroupBuyController extends BaseController {
    @Autowired
    private GroupBuyService groupBuyService;

    /**
     * 查询【请填写功能名称】列表
     */
    @ApiOperation("获取拼团列表")
    @RequiresPermissions("product:buy:list")
    @GetMapping("/list")
    public Result<TableDataInfo<GroupBuy>> list(GroupBuyQueryReq groupBuyQueryReq) {
        startPage();
      List<GroupBuy>  list= groupBuyService.groupList(GroupBuy.queryBuild(groupBuyQueryReq));
//        List<GroupBuy> list = groupBuyService.list();
//        List<GroupBuy> list = groupBuyService.list(GroupBuy.queryBuild(groupBuyQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @ApiOperation("导出拼团列表")
    @RequiresPermissions("product:buy:export")
    @Log(title = "导出拼团", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GroupBuy groupBuy) {
        List<GroupBuy> list = groupBuyService.list(groupBuy);
        ExcelUtil<GroupBuy> util = new ExcelUtil<GroupBuy>(GroupBuy.class);
        util.exportExcel(response, list, "拼团数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @ApiOperation("获取拼团详细信息")
    @RequiresPermissions("product:buy:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<GroupBuy> getInfo(@PathVariable("id") Long id) {
        return Result.success(groupBuyService.getById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @RequiresPermissions("product:buy:add")
    @Log(title = "新增拼团", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增拼团")
    public Result<String> add(@RequestBody GroupBuySaveReq groupBuySaveReq) {
        return toAjax(groupBuyService.save(GroupBuy.saveBuild(groupBuySaveReq)));
    }

    /**
     * 修改【请填写功能名称】
     */
    @RequiresPermissions("product:buy:edit")
    @Log(title = "修改拼团", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改拼团")
    public Result<String> edit(@PathVariable Long id, @RequestBody GroupBuyEditReq groupBuyEditReq) {
        return toAjax(groupBuyService.updateById(GroupBuy.editBuild(id,groupBuyEditReq)));
    }

    /**
     * 删除【请填写功能名称】
     */
    @RequiresPermissions("product:buy:remove")
    @Log(title = "删除拼团", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation("删除拼团")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(groupBuyService.removeBatchByIds(ids));
    }
}
